@@ -2,20 +2,21 @@
 
 import argparse
 import gettext
-import os
+from pathlib import Path
+from typing import Callable
 
 
 def _setup_i18n():
     """Setup internationalization."""
-    argparse._ = _get_i18n_func('argparse')
-    return _get_i18n_func('sshoot')  # default domain
+    argparse._ = _get_i18n_func("argparse")
+    return _get_i18n_func("sshoot")  # default domain
 
 
-def _get_i18n_func(domain):
+def _get_i18n_func(domain: str):
     """Return the internationalization function."""
-    localedir = os.path.join(os.path.dirname(__file__), 'locale')
+    localedir = Path(__file__).parent / "locale"
     g = gettext.translation(domain, localedir=localedir, fallback=True)
     return g.gettext
 
 
-_ = _setup_i18n()
+_: Callable[[str], str] = _setup_i18n()
